summaryrefslogtreecommitdiffstats
path: root/src/import/chips/p9/utils
diff options
context:
space:
mode:
authorSumit Kumar <sumit_kumar@in.ibm.com>2017-07-13 04:35:57 -0500
committerSachin Gupta <sgupta2m@in.ibm.com>2017-07-26 08:59:09 -0400
commit2c55bc77aed85f759288e5e424ac0a355ae5ee47 (patch)
tree7fc9bf09533e127f481456ef23a67b385413c60b /src/import/chips/p9/utils
parent68ff073f4961f0e5b4cde9fd145ff2ef9fc00774 (diff)
downloadtalos-sbe-2c55bc77aed85f759288e5e424ac0a355ae5ee47.tar.gz
talos-sbe-2c55bc77aed85f759288e5e424ac0a355ae5ee47.zip
GPTR/Overlays stage-2 support
-Updated ringClass to include Gptr for Nest/EQ/EX/EC to support CME/SGPE. - Bug fixes: - big endian to local host endian conversion - now also processing Gptr rings in RT_CME/SGPE sysPhases - improved error checking, error capturing and trace outs Change-Id: Idfc19bdf1b7187d6f75c459f7ddbeda80ccfec28 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/43080 Reviewed-by: Claus M. Olsen <cmolsen@us.ibm.com> Reviewed-by: Thi N. Tran <thi@us.ibm.com> Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: PPE CI <ppe-ci+hostboot@us.ibm.com> Tested-by: Hostboot CI <hostboot-ci+hostboot@us.ibm.com> Reviewed-by: Jennifer A. Stofer <stofer@us.ibm.com> Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/43201 Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Sachin Gupta <sgupta2m@in.ibm.com>
Diffstat (limited to 'src/import/chips/p9/utils')
-rw-r--r--src/import/chips/p9/utils/imageProcs/p9_infrastruct_help.H2
-rw-r--r--src/import/chips/p9/utils/imageProcs/p9_ring_identification.H19
-rw-r--r--src/import/chips/p9/utils/imageProcs/p9_scan_compression.H12
3 files changed, 22 insertions, 11 deletions
diff --git a/src/import/chips/p9/utils/imageProcs/p9_infrastruct_help.H b/src/import/chips/p9/utils/imageProcs/p9_infrastruct_help.H
index 508a6bc4..96964dae 100644
--- a/src/import/chips/p9/utils/imageProcs/p9_infrastruct_help.H
+++ b/src/import/chips/p9/utils/imageProcs/p9_infrastruct_help.H
@@ -54,6 +54,8 @@ const uint32_t MAX_NOOF_DD_LEVELS_IN_IMAGE = 20;
#define NUM_OF_QUADS 6
#define CORES_PER_QUAD (NUM_OF_CORES/NUM_OF_QUADS)
+#define INFRASTRUCT_RC_SUCCESS 0
+
enum SYSPHASE
{
SYSPHASE_HB_SBE = 0,
diff --git a/src/import/chips/p9/utils/imageProcs/p9_scan_compression.H b/src/import/chips/p9/utils/imageProcs/p9_scan_compression.H
index 93ff8a44..ef4d8825 100644
--- a/src/import/chips/p9/utils/imageProcs/p9_scan_compression.H
+++ b/src/import/chips/p9/utils/imageProcs/p9_scan_compression.H
@@ -279,9 +279,15 @@ int rs4_extract_cmsk(CompressedScanData* i_rs4,
#endif // __ASSEMBLER__
-// This function prints out the raw decompressed ring content in the same
-// format that it appears as in EKB's ifCompiler generated raw ring
-// files, i.e. *.bin.srd (DATA) and *.bin.srd.bitsModified (CARE).
+/// Function: print_raw_ring()
+/// @brief: Prints out the raw decompressed RS4 ring content.
+///
+/// Desc.:It displays the raw decompressed ring content in the same
+/// format that it appears as in EKB's ifCompiler generated raw ring
+/// files, i.e. *.bin.srd (DATA) and *.bin.srd.bitsModified (CARE).
+///
+/// \param[in] data Its Data (*.bin.srd) or Care (*.bin.srd.bitsModified)
+/// \param[in] bits Length of raw ring in bits
void print_raw_ring( uint8_t* data, uint32_t bits);
OpenPOWER on IntegriCloud
diff --git a/src/import/chips/p9/utils/imageProcs/p9_ring_identification.H b/src/import/chips/p9/utils/imageProcs/p9_ring_identification.H
index f1268765..400e8a37 100644
--- a/src/import/chips/p9/utils/imageProcs/p9_ring_identification.H
+++ b/src/import/chips/p9/utils/imageProcs/p9_ring_identification.H
@@ -83,14 +83,17 @@ enum VpdKeyword
enum VpdRingClass
{
VPD_RING_CLASS_NEST = 0, // Indicates NEST [common] rings, except GPTR #G rings.
- VPD_RING_CLASS_GPTR = 1, // Indicates GPTR #G [common]rings
- VPD_RING_CLASS_EQ = 2, // Indicates EQ [common] rings
- VPD_RING_CLASS_EX = 3, // Indicates EX [common] rings
- VPD_RING_CLASS_EC = 4, // Indicates EC [common] rings
- VPD_RING_CLASS_EQ_INS = 5, // Indicates EQ instance rings
- VPD_RING_CLASS_EX_INS = 6, // Indicates EX instance rings
- VPD_RING_CLASS_EC_INS = 7, // Indicates EC instance rings
- VPD_RING_CLASS_LAST = 8,
+ VPD_RING_CLASS_GPTR_NEST = 1, // Indicates GPTR #G [common]rings-NEST
+ VPD_RING_CLASS_GPTR_EQ = 2, // Indicates GPTR #G [common]rings-EQ
+ VPD_RING_CLASS_GPTR_EX = 3, // Indicates GPTR #G [common]rings-EX
+ VPD_RING_CLASS_GPTR_EC = 4, // Indicates GPTR #G [common]rings-EC
+ VPD_RING_CLASS_EQ = 5, // Indicates EQ [common] rings
+ VPD_RING_CLASS_EX = 6, // Indicates EX [common] rings
+ VPD_RING_CLASS_EC = 7, // Indicates EC [common] rings
+ VPD_RING_CLASS_EQ_INS = 8, // Indicates EQ instance rings
+ VPD_RING_CLASS_EX_INS = 9, // Indicates EX instance rings
+ VPD_RING_CLASS_EC_INS = 10, // Indicates EC instance rings
+ VPD_RING_CLASS_LAST = 11,
};